/* -*- mode:prolog; -*-
 ******************************************************************
 * $Id$
 * Copyright (C) 2008 by INRIA 
 * Author: Eric de la Clergerie <Eric.De_La_Clergerie@inria.fr>
 * ----------------------------------------------------------------
 *
 *  french.tag -- Petite grammaire TA du franais
 *
 * ----------------------------------------------------------------
 * Description
 * 
 * ----------------------------------------------------------------
 */

%% Module DyALog pour grer les ancrages des arbres
:-require 'tag_generic.pl'.

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% Partie declaration
%%   Celle-ci peut etre incluse dans un fichier separee, par example
%%   base.plh
%%   et remplace par la directive suivante
%% :-include 'header.plh'.

%% Generique pour les TAG
:-features( tag_tree, [ family, name, tree ] ).
:-features( tag_anchor, [name, coanchors, equations ] ).

%% Traits pour les non-terminaux de la grammaire
%% Non terminaux en notation anglaise:
%% VP = Verbal Phrase = SV ou GV (syntagme ou groupe verbal)

:-features(det,[kind,gen,num]).
:-features(adj,[gen,num]).
:-features(n,[gen,num,anim]).
:-features(np,[gen,num,anim]).
:-features(vp,[num,mode]).
:-features(v,[num,mode,neg]).

%% Domaines (finis) de valeurs pour certains traits
:-finite_set(gen,[fem,masc]).
:-finite_set(num,[sing,plur]).
:-finite_set(bool,[+,-]).
:-finite_set(dcat,[def,indef]).
:-finite_set(mode,[ind,subj,inf]).

%% Association des structures de traits aux non terminaux
:-tag_features(det,det{},det{}).
:-tag_features(adj,adj{},adj{}).
:-tag_features(n,n{},n{}).
:-tag_features(np,np{},np{}).
:-tag_features(vp,vp{},vp{}).
:-tag_features(v,v{},v{}).

%% Declarations des motifs d'ancrage
:-tag_anchor{ name => n0vn1pn2,
              coanchors => [ p2 ]
	    }.

:-tag_anchor{ name => np,
              equations => [[A,B]^(bot=np{num=>A,gen=>B} at np) ]
	    }.

%% Fin des declarations
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% La requte

?-recorded('N'(N)), tag_phrase(s,0,N).

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Les arbres de la grammaire

%% Catgories trs lmentaires

tag_tree{ name => d,		% Determinant
	  family => d,
	  tree => tree <>det
	}.

tag_tree{ name => np,		% Pronoms et noms propres
	  family => np,
	  tree => tree id=np at <>np
	}.

tag_tree{ name => prep,		% Prepositions
	  family => prep,
	  tree => tree <>prep
	}.

%% Quelques arbres plus complexes

tag_tree{ name => dn,		% Determinant Nom
	  family => np,
	  tree => tree
	bot=np{num => X0} at
	np(
	   top=det{num => X0, gen => X1}
	  at det,
	   id=n_
	  and top=n{num => X0, gen => X1}
	  at <>n
	  )
	}.

tag_tree{ name => an,		% Adjectif Nom
	  family => adj,
	  tree => auxtree bot=I at n(
				     top=adj{num=>N,gen=>G} at <>adj,
				     bot=I::n{num=>N,gen=>G} at *n
				    )
	}.

tag_tree{ name => na,		% Nom Adjectif
	  family => adj,
	  tree => auxtree bot=I at n(bot=I::n{num=>N,gen=>G} at *n,
				     top=adj{num=>N,gen=>G} at <>adj)
	}.

tag_tree{ name=>n0v,		% Verbe intransitif
	  family=>n0v,
	  tree => tree s(id=subject and top=np{num=>N} at np,
			 top=vp{num=>N} and bot=vp{mode=>M2,num=>N2}
			at vp(bot=v{mode=>M2,num=>N2} at <>v
			     )
			)
	}.


tag_tree{ name=>n0vn1,		% Verbe transitif
	  family=>n0vn1,
	  tree => tree s(id=subject and top=np{num=>N} at np,
			 top=vp{num=>N} and bot=vp{mode=>M2,num=>N2}
			at vp(bot=v{mode=>M2,num=>N2} at <>v,
			      id=object at np))
	}.

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Lexique syntaxique (lemmes)

tag_lemma('*DET*',det,tag_anchor{ name => d }).
tag_lemma('*PN*',np,tag_anchor{ name => np,
				equations => [bot = np{num=>sing} at np]
			      }
	 ).
tag_lemma('*PREP*',prep,tag_anchor{ name => prep }).
tag_lemma('*PRON*',np,tag_anchor{ name => np }).
tag_lemma(cigare,n,tag_anchor{ name => np }).
tag_lemma(tlescope,n,tag_anchor{ name => np }).
tag_lemma(pomme,n,tag_anchor{ name => np }).
tag_lemma(manger,v,tag_anchor{ name => [n0v,n0vn1] }).
tag_lemma(regarder,v,tag_anchor{ name => n0vn1 }).
tag_lemma(fumer,v,tag_anchor{ name => [n0v,n0vn1] }).
tag_lemma(nager,v,tag_anchor{ name => n0v }).
tag_lemma(vert,adj,tag_anchor{ name => adj }).
tag_lemma(donner,v,tag_anchor{ name => n0vn1pn2, coanchors => [p2=] }).

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Lexique morphologique (mots)

tag_lexicon(le,'*DET*',det,det{kind=>def,gen=>masc,num=>sing}).
tag_lexicon(la,'*DET*',det,det{kind=>def,gen=>fem,num=>sing}).
tag_lexicon(un,'*DET*',det,det{kind=>indef,gen=>masc,num=>sing}).
tag_lexicon(une,'*DET*',det,det{kind=>indef,gen=>fem,num=>sing}).
tag_lexicon(les,'*DET*',det,det{kind=>def,num=>plur}).
tag_lexicon(des,'*DET*',det,det{kind=>indef,num=>plur}).

tag_lexicon('Pierre','*PN*',np,np{gen=>masc}).
tag_lexicon('Paul','*PN*',np,np{gen=>masc}).
tag_lexicon('Jean','*PN*',np,np{gen=>masc}).
tag_lexicon('Anne','*PN*',np,np{gen=>fem}).
tag_lexicon('Sophie','*PN*',np,np{gen=>fem}).

tag_lexicon(cigare,cigare,n,n{gen=>masc,num=>sing,anim=> (-)}).
tag_lexicon(cigares,cigare,n,n{gen=>masc,num=>plur,anim=> (-)}).
tag_lexicon(pomme,pomme,n,n{gen=>fem,num=>sing,anim=> (-)}).
tag_lexicon(pommes,pomme,n,n{gen=>fem,num=>plur,anim=> (-)}).
tag_lexicon(tlescope,tlescope,n,n{gen=>masc,num=>sing,anim=> (-)}).
tag_lexicon(tlescopes,tlescope,n,n{gen=>masc,num=>plur,anim=> (-)}).

tag_lexicon(fumer,fumer,v,v{mode=>inf}).
tag_lexicon(fume,fumer,v,v{num=>sing,mode=>mode[ind,subj]}).
tag_lexicon(fument,fumer,v,v{num=>plur,mode=>mode[ind,subj]}).

tag_lexicon(manger,manger,v,v{mode=>inf}).
tag_lexicon(mange,manger,v,v{num=>sing,mode=>mode[ind,subj]}).
tag_lexicon(mangent,manger,v,v{num=>plur,mode=>mode[ind,subj]}).

tag_lexicon(regarder,regarder,v,v{mode=>inf}).
tag_lexicon(regarde,regarder,v,v{num=>sing,mode=>mode[ind,subj]}).
tag_lexicon(regardent,regarder,v,v{num=>plur,mode=>mode[ind,subj]}).

tag_lexicon(nager,nager,v,v{mode=>inf}).
tag_lexicon(nage,nager,v,v{num=>sing,mode=>mode[ind,subj]}).
tag_lexicon(nagent,nager,v,v{num=>plur,mode=>mode[ind,subj]}).

tag_lexicon(donner,donner,v,v{mode=>inf}).
tag_lexicon(donne,donner,v,v{num=>sing,mode=>mode[ind,subj]}).
tag_lexicon(donnent,donner,v,v{num=>plu,mode=>mode[ind,subj]}).

tag_lexicon(vert,vert,adj,adj{gen=>masc,num=>sing}).
tag_lexicon(verts,vert,adj,adj{gen=>masc,num=>plur}).
tag_lexicon(verte,vert,adj,adj{gen=>fem,num=>sing}).
tag_lexicon(vertes,vert,adj,adj{gen=>fem,num=>plur}).

tag_lexicon(de,'*PREP*',prep,prep).
tag_lexicon(,'*PREP*',prep,prep).
tag_lexicon(avec,'*PREP*',prep,prep).

tag_lexicon(il,'*PRON*',np,np{gen=>masc,num=>sing}).

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%% Exercice 3: Groupe Prpositionnels

tag_tree{ name => nppp,
	  family => prep,
	  tree => auxtree top=I at np(bot=I at *np,pp(<>prep,np))
	}.

tag_tree{ name => vppp,
	  family => prep,
	  tree => auxtree top=I at vp(bot=I at *vp,pp(<>prep,np))
	}.

%% Exercice 4: Catgorisation verbes ditransitifs

tag_tree{ name => n0vn1pn2,
	  family => n0vn1pn2,
	  tree => tree s(id=subject at np,
			 vp(<>v,
			    id=object at np,
			    pp(id=p2 at prep,
			       id=preparg at np
			      )))
	}.

%% Exercice 5: Gestion des relatives

tag_tree{ name => r0v,
	  family => n0v,
	  tree => auxtree np(bot=np{num=>N} at *np,
			     s(np([qui]),
			       s( -np([]),
				  top=vp{num=>N} and bot=vp{mode=>M2,num=>N2}
				at vp(
				      bot=v{mode=>M2,num=>N2} at <>v
				     )
				)))
	}.

tag_tree{ name => r0vn1,
	  family => n0vn1,
	  tree => auxtree np(bot=np{num=>N} at *np,
			     s(np([qui]),
			       s( -np([]),
				  top=vp{num=>N} and bot=vp{mode=>M2,num=>N2}
				at vp(bot=v{mode=>M2,num=>N2} at <>v,
				     id=object at np)
				)))
	}.

tag_tree{ name => r1n0v,
	  family => n0vn1,
	  tree => auxtree np(bot=np{num=>N} at *np,
			     s(np([que]),
			       s( id=subject at np,
				  top=vp{num=>N} and bot=vp{mode=>M2,num=>N2}
				at vp(bot=v{mode=>M2,num=>N2} at <>v,
				     -np([]))
				)))
	}.

tag_tree{ name => r0vn1pn2,
	  family => n0vn1pn2,
	  tree => auxtree np(bot=np{num=>N} at *np,
			     s(np([qui]),
			       s( -np([]),
				  top=vp{num=>N} and bot=vp{mode=>M2,num=>N2}
				at vp(bot=v{mode=>M2,num=>N2} at <>v,
				     id=subject at np,
				     pp(id=p2 at prep,
					id=preparg at np
				       )))))
	}.

tag_tree{ name => r1n0vpn2,
	  family => n0vn1pn2,
	  tree => auxtree np(*np,
			     s(np([que]),
			       s( id=subject at np,
				  bot=vp{mode=>M2,num=>N2}
				at vp( bot=v{mode=>M2,num=>N2} at <>v,
				     -np([]),
				     pp(id=p2 at prep,
					id=preparg at np
				       )))))
	}.


%% Exercice 6: Catgorisation 2: verbes avec infinitives

tag_tree{ name => vvp,
	  family => vvp,
	  tree => auxtree
	bot=vp{mode=>M2,num=>N2}
	at vp( bot=v{mode=>M2,num=>N2} at <>v,
	       bot=vp{mode=>inf} at *vp)
	}.

tag_lemma(devoir,v,tag_anchor{name=>vvp}).
tag_lexicon(doit,devoir,v,v{num=>sing,mode=>ind}).
tag_lexicon(devoir,devoir,v,v{mode=>inf}).

tag_lemma(pouvoir,v,tag_anchor{name=>vvp}).
tag_lexicon(peut,pouvoir,v,v{num=>sing,mode=>ind}).
tag_lexicon(pouvoir,pouvoir,v,v{mode=>inf}).

%% Exercice 7: Catgorisation 3: verbes avec compltives

tag_tree{ name => vs1,
	  family => vs1,
	  tree => auxtree s(id=subject and bot=np{num=>N} at np,
			    top=vp{mode=>M1,num=>N} and bot=vp{mode=>M2,num=>N2}
			   at vp(bot=v{mode=>M2,num=>N2} at <>v,
				 s(comp([que]),
				   *s)))
	}.

tag_lemma(penser,v,tag_anchor{name=>vs1}).
tag_lexicon(pense,penser,v,v{num=>sing,mode=>ind}).
tag_lexicon(penser,penser,v,v{mode=>inf}).
				      
tag_lemma(vouloir,v,tag_anchor{name=>[vvp,vs1]}).
tag_lexicon(veut,vouloir,v,v{num=>sing,mode=>ind}).
tag_lexicon(vouloir,vouloir,v,v{mode=>inf}).

%% Exercice 7: Ngation

tag_tree{ name => neg_tense,
	  family => negation,
	  tree => auxtree bot=v{mode=>M, neg=> (+), num=>N}
	at v([ne],
	     bot=v{mode=>M::mode[ind,subj], neg=> (-), num=>N} at *v,
	     [pas]
	    )
	}.

tag_tree{ name => neg_inf,
	  family => negation,
	  tree => auxtree bot=v{mode=>inf, neg=> (+)}
	at v([ne],
	     [pas],
	     bot=v{mode=>inf, neg=> (-)} at *v
	    )
	}.


